# Conditionals to help with missing test dependencies
%if 0%{?mageia}
%bcond_with checker
%endif

Name:          rxjava
Version:       1.1.8
Release:       %mkrel 5
Group:         Development/Java
Summary:       Reactive Extensions for the JVM
License:       ASL 2.0
URL:           https://github.com/ReactiveX/RxJava
Source0:       https://github.com/ReactiveX/RxJava/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:       https://repo1.maven.org/maven2/io/reactivex/%{name}/%{version}/%{name}-%{version}.pom

BuildRequires: maven-local
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
%if %{with checker}
BuildRequires: mvn(com.google.guava:guava)
BuildRequires: mvn(com.pushtorefresh.java-private-constructor-checker:checker)
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.mockito:mockito-core)
%endif

# RxJava adaptation of jctools
Provides:      bundled(jctools-core) = 1.2-SNAPSHOT

BuildArch:     noarch

%description
RxJava a library for composing asynchronous and
event-based programs using observable sequences
for the Java VM.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n RxJava-%{version}
# Cleanup
find . -name '*.class' -print -delete
find . -name '*.jar' -print -delete

cp -p %{SOURCE1} pom.xml

# Add OSGi support
%pom_xpath_inject "pom:project" "<packaging>bundle</packaging>"
%pom_add_plugin org.apache.felix:maven-bundle-plugin:2.3.7 . '
<extensions>true</extensions>
<configuration>
  <instructions>
    <Bundle-SymbolicName>io.reactivex.rxjava</Bundle-SymbolicName>
    <Bundle-Name>${project.name}</Bundle-Name>
    <Bundle-Vendor>ReactiveX</Bundle-Vendor>
    <Bundle-Version>${project.version}</Bundle-Version>
  </instructions>
</configuration>
<executions>
  <execution>
    <id>bundle-manifest</id>
    <phase>process-classes</phase>
    <goals>
      <goal>manifest</goal>
    </goals>
  </execution>
</executions>'

# Fix javadoc plugin configuration
%pom_add_plugin org.apache.maven.plugins:maven-javadoc-plugin:2.9.1 . '
<configuration>
  <excludePackageNames>*.internal.*</excludePackageNames>
</configuration>'

%if %{with checker}

# Add test deps
%pom_add_dep junit:junit:4.12:test
%pom_add_dep org.mockito:mockito-core:1.10.19:test
%pom_add_dep com.google.guava:guava:19.0:test
%pom_add_dep com.pushtorefresh.java-private-constructor-checker:checker:1.2.0:test

# This test take too much time on ARM builder e.g.:
# Time elapsed: 3.027 sec  <<< ERROR!
# org.junit.runners.model.TestTimedOutException: test timed out after 3000 milliseconds
rm src/test/java/rx/internal/operators/OperatorMergeMaxConcurrentTest.java \
 src/test/java/rx/internal/operators/OperatorMergeTest.java \
 src/test/java/rx/internal/operators/OperatorPublishTest.java \
 src/test/java/rx/internal/operators/OperatorRepeatTest.java \
 src/test/java/rx/internal/operators/OperatorRetryTest.java \
 src/test/java/rx/subjects/ReplaySubjectBoundedConcurrencyTest.java \
 src/test/java/rx/subjects/ReplaySubjectConcurrencyTest.java
# Require OperatorRetryTest
rm src/test/java/rx/internal/operators/OperatorRetryWithPredicateTest.java

%endif

%mvn_file io.reactivex:%{name} %{name}

%build

%if %{without checker}
opts="-f"
%endif
# Test skipped unavailable test dep
%mvn_build $opts -- -Dproject.build.sourceEncoding=UTF-8

%install
%mvn_install

%files -f .mfiles
%doc CHANGES.md README.md
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE



%changelog
* Mon May 27 2024 ns80 <ns80> 1.1.8-5.mga10
+ Revision: 2068168
- rebuild for java 21

* Sat Mar 26 2022 umeabot <umeabot> 1.1.8-4.mga9
+ Revision: 1827359
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 1.1.8-3.mga8
+ Revision: 1508067
- Mageia 8 Mass Rebuild

* Fri Sep 21 2018 umeabot <umeabot> 1.1.8-2.mga7
+ Revision: 1291462
- Mageia 7 Mass Rebuild

* Sun Feb 11 2018 daviddavid <daviddavid> 1.1.8-1.mga7
+ Revision: 1200452
- Update to 1.1.8 (sync with fc28)
- bundle jctools
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 1.0.13-3.mga6
+ Revision: 978149
- First rebuild of the java stack
- sync package rxjava with fedora
- imported package rxjava


* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Aug 07 2015 gil cattaneo <puntogil@libero.it> 1.0.13-1
- Update to 1.0.13

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri May 22 2015 gil cattaneo <puntogil@libero.it> 1.0.11-1
- update to 1.0.11

* Tue May 19 2015 gil cattaneo <puntogil@libero.it> 1.0.10-1
- initial rpm
